@@ -193,6 +193,11 @@ class _WiserRoom(object):
         if self._send_command({"Name": name.title()}):
             self._name = name.title()
 
+    @property
+    def number_of_smartvalves(self) -> int:
+        """Get number of smartvalves associated with room"""
+        return len(self._data.get("SmartValveIds", []))
+
     @property
     def override_target_temperature(self) -> float:
         """Get the override target temperature of the room"""
@@ -223,6 +228,11 @@ class _WiserRoom(object):
         """Get the scheduled target temperature for the room"""
         return tf._from_wiser_temp(self._data.get("ScheduledSetPoint", TEMP_MINIMUM))
 
+    @property
+    def smartvalve_ids(self) -> list:
+        """Get list of smartvalve ids associated with room"""
+        return sorted(self._data.get("SmartValveIds", []))
+
     @property
     def target_temperature_origin(self) -> str:
         """Get the origin of the target temperature setting for the room"""
